@@ -63,9 +63,6 @@ class PyodbcResource(object):
                                           timeout = int(properties.get('timeout', '0')),
                                           unicode_results = (properties.get('unicode_results', 'false') == 'true'))
 
-    def add_output_converter(self, sqltype, func):
-        self._connection.add_output_converter(sqltype, func)
-
     @property
     def autocommit(self):
         return self._connection.autocommit
@@ -74,9 +71,6 @@ class PyodbcResource(object):
     def autocommit(self, value):
         self._connection.autocommit = value
 
-    def clear_output_converters(self):
-        self._connection.clear_output_converters()
-
     def close(self):
         self._connection.close()
 
@@ -89,9 +83,6 @@ class PyodbcResource(object):
     def execute(self, query, *args):
         return PyodbcCursorContext(self._connection.execute(query, *args))
 
-    def getinfo(self, type):
-        return self._connection.getinfo(type)
-
     def rollback(self):
         self._connection.rollback()
 
